@@ -3,7 +3,7 @@ BEGIN {
   $Web::Machine::FSM::States::AUTHORITY = 'cpan:STEVAN';
 }
 # ABSTRACT: The States for Web Machine
-$Web::Machine::FSM::States::VERSION = '0.14';
+$Web::Machine::FSM::States::VERSION = '0.15';
 use strict;
 use warnings;
 
@@ -744,7 +744,7 @@ Web::Machine::FSM::States - The States for Web Machine
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -815,6 +815,14 @@ John SJ Anderson <genehack@genehack.org>
 
 =item *
 
+Mike Raynham <enquiries@mikeraynham.co.uk>
+
+=item *
+
+Mike Raynham <mike.raynham@spareroom.co.uk>
+
+=item *
+
 Olaf Alders <olaf@wundersolutions.com>
 
 =item *
