@@ -3,7 +3,7 @@ BEGIN {
   $Web::Machine::I18N::AUTHORITY = 'cpan:STEVAN';
 }
 # ABSTRACT: The I18N support for HTTP information
-$Web::Machine::I18N::VERSION = '0.14';
+$Web::Machine::I18N::VERSION = '0.15';
 use strict;
 use warnings;
 
@@ -21,7 +21,7 @@ Web::Machine::I18N - The I18N support for HTTP information
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -83,6 +83,14 @@ John SJ Anderson <genehack@genehack.org>
 
 =item *
 
+Mike Raynham <enquiries@mikeraynham.co.uk>
+
+=item *
+
+Mike Raynham <mike.raynham@spareroom.co.uk>
+
+=item *
+
 Olaf Alders <olaf@wundersolutions.com>
 
 =item *
